@@ -1,9 +1,9 @@
-# @(#)Ident: Provision.pm 2013-05-08 10:24 pjf ;
+# @(#)Ident: Provision.pm 2013-05-09 18:15 pjf ;
 
 package Module::Provision;
 
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.12.%d', q$Rev: 3 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.12.%d', q$Rev: 5 $ =~ /\d+/gmx );
 
 use Moose;
 
@@ -30,7 +30,7 @@ Module::Provision - Create Perl distributions with VCS and selectable toolchain
 
 =head1 Version
 
-This documents version v0.12.$Rev: 3 $ of L<Module::Provision>
+This documents version v0.12.$Rev: 5 $ of L<Module::Provision>
 
 =head1 Synopsis
 
@@ -97,7 +97,8 @@ body. This means that so long as one detail line is added to the
 change log no other commit message text is required. The following
 makes for a suitable C<git log> alias:
 
-   alias gl='git log -10 --pretty=format:"%h %ci %s" | cut -c1-79'
+   alias gl='git log -5 --pretty=format:"%h %ci %s" | \
+      cut -d" " -f1-3,5- | cut -c1-79'
 
 The default VCS used by the create distribution methods can be
 changed from the command line or from the configuration file
